@@ -28,8 +28,10 @@ from .cotrans.cotrans import cotrans
 from .cotrans.cotrans_get_coord import cotrans_get_coord
 from .cotrans.cotrans_set_coord import cotrans_set_coord
 
-from .mms import mms_load_mec, mms_load_fgm, mms_load_scm, mms_load_edi, mms_load_edp, mms_load_eis, mms_load_feeps, \
-    mms_load_hpca, mms_load_fpi, mms_load_aspoc, mms_load_dsp, mms_load_fsm, mms_load_state
+from .mms import mms_load_mec, mms_load_fgm, mms_load_scm, mms_load_edi, \
+    mms_load_edp, mms_load_eis, mms_load_feeps, \
+    mms_load_hpca, mms_load_fpi, mms_load_aspoc, \
+    mms_load_dsp, mms_load_fsm, mms_load_state
 from .mms.feeps.mms_feeps_pad import mms_feeps_pad
 from .mms.feeps.mms_feeps_gpd import mms_feeps_gpd
 from .mms.eis.mms_eis_pad import mms_eis_pad
@@ -37,6 +39,7 @@ from .mms.hpca.mms_hpca_calc_anodes import mms_hpca_calc_anodes
 from .mms.hpca.mms_hpca_spin_sum import mms_hpca_spin_sum
 
 from .maven import maven_load
+from .sosmag.load import sosmag_load
 
 from . import erg
 from . import ulysses
