@@ -2,11 +2,12 @@ import numpy as np
 from pytplot import get_data, store_data, options
 from pyspedas import tnames
 
-def mms_hpca_spin_sum(probe='1', datatypes=None, species=['hplus', 'oplus', 'oplusplus', 'heplus', 'heplusplus'], fov=['0', '360'], avg=False):
+def mms_hpca_spin_sum(probe='1', datatypes=None, species=['hplus', 'oplus', 'oplusplus', 'heplus', 'heplusplus'], fov=['0', '360'], avg=False, suffix=''):
     """
     This function will sum (or average, when the avg keyword is set to True) the HPCA data over each spin
     
-    Parameters:
+    Parameters
+    ----------
         fov : list of str
             field of view, in angles, from 0-360
 
@@ -25,7 +26,8 @@ def mms_hpca_spin_sum(probe='1', datatypes=None, species=['hplus', 'oplus', 'opl
         avg: bool
             spin-average the data instead of spin-summing the data
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
     """
 
@@ -40,14 +42,14 @@ def mms_hpca_spin_sum(probe='1', datatypes=None, species=['hplus', 'oplus', 'opl
     if not isinstance(probe, str):
         probe = str(probe)
 
-    az_times, start_az = get_data('mms'+probe+'_hpca_start_azimuth')
+    az_times, start_az = get_data('mms'+probe+'_hpca_start_azimuth'+suffix)
 
     spin_starts = np.argwhere(start_az == 0)
     output_vars = []
     species_map = {'hplus': 'H+', 'oplus': 'O+', 'heplus': 'He+', 'heplusplus': 'He++'}
 
     for datatype in datatypes:
-        vars_to_sum = tnames(datatype+'_elev_'+fov[0]+'-'+fov[1])
+        vars_to_sum = tnames(datatype+suffix+'_elev_'+fov[0]+'-'+fov[1])
         for var in vars_to_sum:
             var_species = var.split('_')[2]
             data = get_data(var, xarray=True)
@@ -62,8 +64,9 @@ def mms_hpca_spin_sum(probe='1', datatypes=None, species=['hplus', 'oplus', 'opl
             options(var+'_spin', 'spec', True)
             options(var+'_spin', 'ylog', True)
             options(var+'_spin', 'zlog', True)
-            options(var+'_spin', 'Colormap', 'jet')
+            options(var+'_spin', 'Colormap', 'spedas')
             options(var+'_spin', 'ztitle', species_map[var_species] + ' ' + var.split('_')[3] + ' (cm^2-s-sr-eV)^-1')
-            options(var+'_spin', 'ytitle', species_map[var_species] + ' Energy (eV)')
+            options(var+'_spin', 'ytitle', species_map[var_species])
+            options(var+'_spin', 'ysubtitle', 'Energy [eV]')
             output_vars.append(var+'_spin')
     return output_vars
\ No newline at end of file
